/****************************************************************************************
* This program accepts a command line argument of either d, m, or y, and returns the day,
*   month, or year as the errorlevel.  This is meant to be used in a Windows NT cmd prompt
*   window with the cmd extensions enabled.  These extensions include a %ERRORLEVEL% 
*   environment variable that can be stored into another environment variable.
*
* 11 Dec. 1997 - Initial work, and notes.
*
* 16 Dec. 1997 - Actually implemented the date checking functionality.  Works as
*                  advertised.
*
* 29 Dec. 1997 - Started working on adding time checking capability.  Got it added.
*
* Compile: cl /nologo /W3 /D "WIN32" /D "CONSOLE"  /Zp1 /c dtelevel.c
* Link   : link /NOLOGO /MACHINE:IX86 /SUBSYSTEM:CONSOLE /OUT:dtelevel.exe dtelevel.obj
*          kernel32.lib
****************************************************************************************/
#include <stdio.h>
#include <stdlib.h>

#include <windows.h>
#include <winnt.h>
#include <winbase.h>

void main(int argc, char *argv[]) {
  unsigned long  rtc;                            /* Return code */
  SYSTEMTIME     datetime;                       /* Date and time information */

  printf("\nDTELEVEL for WinNT\n");
  printf("By: Paul Trout, Bionic Fish Software Foundry\n");
  printf("30 Dec. 1997 - V1R1\n");

  if(argc<2) {                                   /* Usage message */
    printf("\nUSAGE: dtelevel [m|d|y|c|h|i|s]\n");
    printf("\n");
    printf(" Where m = Month\n");
    printf("       d = Day\n");
    printf("       y = Year\n");
    printf("       c = Century\n");
    printf("\n");
    printf("       h = Hour\n");
    printf("       i = mInutes\n");
    printf("       s = Seconds\n");
    exit(0);
  }

  GetLocalTime(&datetime);                       /* Retrieve system date and time */

  switch(argv[1][0]) {                           /* Return data based on command */
    case 'c' :                                   /* c or C is century */
    case 'C' : rtc=(datetime.wYear/100);         /* Calculate century */
               break;                            /* Enough for now */
    case 'd' :
    case 'D' : rtc=datetime.wDay;                /* Get day */
               break;
    case 'h' :
    case 'H' : rtc=datetime.wHour;               /* Get hour */
               break;
    case 'i' :
    case 'I' : rtc=datetime.wMinute;             /* Get minute */
               break;
    case 'm' :
    case 'M' : rtc=datetime.wMonth;              /* Get month */
               break;
    case 's' :
    case 'S' : rtc=datetime.wSecond;             /* Get second */
               break;
    case 'y' :
    case 'Y' : rtc=datetime.wYear;               /* Get full 4 digit year */
               break;
  }

  exit(rtc);                                     /* Return data as errorlevel */
}

